@@ -39,6 +39,4 @@
 #  endif
 #endif
 
-#endif
-
-#define GRANTLEE_TESTS_EXPORT 
+#endif /* GRANTLEE_TEMPLATES_EXPORT_H */
